@@ -32,23 +32,28 @@ rfPermute.default <- function(x, y, ..., nrep = 100, num.cores = NULL) {
     # Create list of permuted y values
     ran.y <- lapply(1:nrep, function(i) sample(rf.call$y))
     
+    call.x <- x
     # Get importance scores for permutations
     #  a list of 3-dimensional arrays of importance scores
     null.dist <- if(num.cores == 1) {
       # Don't use parallelizing if num.cores == 1      
-      lapply(ran.y, .permFunc, x = x, perm.rf.call = rf.call)
+      lapply(ran.y, .permFunc, call.x = call.x, perm.rf.call = rf.call)
     } else if(Sys.info()[["sysname"]] %in% c("Linux", "Darwin")) {
       # Run random forest on Linux or Macs using mclapply
       parallel::mclapply(
-        ran.y, .permFunc, x = x, perm.rf.call = rf.call, mc.cores = num.cores
+        ran.y, .permFunc, call.x = call.x, perm.rf.call = rf.call, mc.cores = num.cores
       )
     } else {
       # Run random forest using parLapply
       tryCatch({
         cl <- parallel::makeCluster(num.cores)
         parallel::clusterEvalQ(cl, require(randomForest))
-        parallel::clusterExport(cl, "x", "rf.call", environment())
-        parallel::parLapply(cl, ran.y, .permFunc, x = x, perm.rf.call = rf.call)
+        parallel::clusterExport(
+          cl = cl, 
+          varlist = c("call.x", "rf.call"), 
+          envir = environment()
+        )
+        parallel::parLapply(cl, ran.y, .permFunc, call.x = call.x, perm.rf.call = rf.call)
       }, finally = parallel::stopCluster(cl))
     }
     
